@@ -233,8 +233,7 @@ class Pipeline(ABC):
             False by default, if set to True will send the log to userLogs  **REQUIRED**
         '''
         #gets UTC time
-        date = datetime.datetime.utcnow()
-        utc_time = calendar.timegm(date.utctimetuple())
+        date = datetime.datetime.now(datetime.timezone.utc)
         result = ""
         #check if severity exists
         temp_args = args
@@ -257,7 +256,7 @@ class Pipeline(ABC):
             #creating log object
             log = {
                 "severity": log_severity.name,
-                "date": utc_time,
+                "date": str(date),
                 "message": result
             }
             #builds readable string and prints it out
