@@ -5,6 +5,8 @@ import mimetypes
 from seams.exceptions import SeamsException, SeamsAPIException
 import json
 import msal
+import os
+AD_AUTH_MODE = os.getenv("AD_AUTH_MODE")
 
 class Seams(object):
     '''
@@ -36,14 +38,21 @@ class Seams(object):
         :returns:
             None
         '''
+        if AD_AUTH_MODE is not None and AD_AUTH_MODE == "local":
+            authority = "https://seams-ad.rjlglims.com/adfs"
+            scopes = ["openid","profile"]
+        else:
+            authority="https://login.microsoftonline.com/{}".format(tenant_id)
+            scopes = ["api://{}/.default".format(app_id)]
+
         app = msal.ConfidentialClientApplication(
                 app_id,
-                authority="https://login.microsoftonline.com/{}".format(tenant_id),
+                authority=authority,
                 client_credential=secret)
         result = None
         result = app.acquire_token_silent(scopes=["api://{}/access_as_user".format(app_id)], account=None)
-        if not result:
-            result = app.acquire_token_for_client(scopes=["api://{}/.default".format(app_id)])
+        if result is None:
+            result = app.acquire_token_for_client(scopes=scopes)
         if "error" in result:
             print("Error connecting with given credentials")
             raise SeamsAPIException(result["error_description"])
